<?php

namespace XenGenTr\XGTStyleV7\XF\Repository;

use XF\Mvc\Entity\Finder;
use XF\Mvc\Entity\Repository;

class MemberStat extends Repository
{

    protected function getSonKayitOlanlarList($onlineCutOff, $limit){

        $daysCutOff = $onlineCutOff / 24;

        $finder = $this->finder('XF:User');
        $finder->where('user_state', 'valid')
            ->where('register_date', '>=', time() - (86400 * $daysCutOff));

        $constraints = $this->applyVisibilityRestrictions();

        if($constraints){
            $finder->whereOr($constraints);
        }

        if($limit)
        {
            $finder->limit($limit);
        }
        return $finder->fetch();

    }

    protected function mergeUserArrays($arrayOne, $arrayTwo){

        $array = array_unique(array_merge($arrayOne, $arrayTwo));
        return $array;
    }

    protected function applyVisibilityRestrictions(){
        $visitor = \XF::visitor();

        if (!$visitor->canBypassUserPrivacy())
        {
            $constraints = [['visible', '!=', 0],
                ['user_id', '=', $visitor->user_id]
            ];

        }else{
            $constraints = null;
        }

        return $constraints;
    }

    protected function applyLimit($users, $limit){

        if($limit === 0)
        {
            return $users;
        }
        elseif(count($users) === 0)
        {
            return $users;
        }
        else
        {
            $users = array_slice($users,0, $limit);
            return $users;
        }
    }

    protected function applyExclusions($users, $excludedUserGroupsString){

        $usersArray = [];
        $excludedUserGroupIdsArray = array_map('intval', explode(',', $excludedUserGroupsString));

        if ($excludedUserGroupIdsArray)
        {
            foreach($users as $user)
            {
                $groupIds = $user['secondary_group_ids'];
                $groupIds[] = $user['user_group_id'];
                $groupIds = array_flip($groupIds);

                if(!array_intersect_key($groupIds, array_flip($excludedUserGroupIdsArray)))
                {
                    $usersArray[] = $user;
                }
            }
            return $usersArray;
        }
        return $users;
    }

    public function getSonKayitOlanlarVeri($daysCutOff, $userLimit)
    {

        $users = $this->getSonKayitOlanlarList($daysCutOff, $userLimit);
        $allUsers = $this->getSonKayitOlanlarList($daysCutOff, 0);
        $counts = count($allUsers);

        return [
            'users' => $users,
            'counts' => $counts
        ];
    }

}